@@ -29,7 +29,7 @@
 #define DEBUG_KP_EFFECT_BLUR_SHARPEN 0
 
 
-#include <kpEffectBlurSharpenCommand.h>
+#include "kpEffectBlurSharpenCommand.h"
 
 #include <kdebug.h>
 #include <klocale.h>
