@@ -30,7 +30,7 @@
 #define DEBUG_KP_EFFECT_REDUCE_COLORS 0
 
 
-#include <kpEffectReduceColors.h>
+#include "imagelib/effects/kpEffectReduceColors.h"
 
 #include <kdebug.h>
 
