@@ -29,7 +29,12 @@
 #define DEBUG_KP_PAINTER 0
 
 
-#include <kpPainter.h>
+#include "kpPainter.h"
+
+#include "kpImage.h"
+#include "pixmapfx/kpPixmapFX.h"
+#include "tools/kpTool.h"
+#include "tools/flow/kpToolFlowBase.h"
 
 #include <cstdio>
 
@@ -39,11 +44,6 @@
 #include <kdebug.h>
 #include <krandom.h>
 
-#include <kpImage.h>
-#include <kpPixmapFX.h>
-#include <kpTool.h>
-#include <kpToolFlowBase.h>
-
 //---------------------------------------------------------------------
 
 // public static
@@ -471,7 +471,7 @@ static QRect WashLineHelper (QPainter *rgbPainter, void *data)
 #endif
 
 
-    // TODO: Rectangle may be too big.  Use QRect::unite() incrementally?
+    // TODO: Rectangle may be too big.  Use QRect::united() incrementally?
     //       Efficiency?
     return didSomething ? pack->readableImageRect : QRect ();
 }
