@@ -1,4 +1,3 @@
-
 /*
    Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
    All rights reserved.
@@ -29,22 +28,24 @@
 #define DEBUG_KP_TOOL_ZOOM 0
 
 
-#include <kpToolZoom.h>
+#include "kpToolZoom.h"
 
-#include <QWidget>
+#include "kpDefs.h"
+#include "document/kpDocument.h"
+#include "pixmapfx/kpPixmapFX.h"
+#include "generic/kpSetOverrideCursorSaver.h"
+#include "layers/tempImage/kpTempImage.h"
+#include "environments/tools/kpToolEnvironment.h"
+#include "tools/kpToolAction.h"
+#include "views/manager/kpViewManager.h"
 
 #include <kdebug.h>
 #include <klocale.h>
+#include <kiconloader.h>
 
-#include <kpDefs.h>
-#include <kpDocument.h>
-#include <kpPixmapFX.h>
-#include <kpSetOverrideCursorSaver.h>
-#include <kpTempImage.h>
-#include <kpToolEnvironment.h>
-#include <kpToolAction.h>
-#include <kpViewManager.h>
+#include <QWidget>
 
+//---------------------------------------------------------------------
 
 struct DrawZoomRectPackage
 {
@@ -78,7 +79,7 @@ kpToolZoom::kpToolZoom (kpToolEnvironment *environ, QWidget *parent)
       d (new kpToolZoomPrivate ())
 {
   // different from objectName()
-  action()->setIcon(KIcon("zoom-original"));
+  action()->setIcon(KDE::icon("zoom-original"));
 }
 
 //---------------------------------------------------------------------
@@ -249,4 +250,3 @@ void kpToolZoom::endDraw (const QPoint &, const QRect &normalizedRect)
 }
 
 
-#include <kpToolZoom.moc>
